pub enum XFrameOptions {
Deny,
SameOrigin,
AllowFrom(String),
}Expand description
Manages X-Frame-Options header
The X-Frame-Options HTTP response header can be used to to avoid click-jacking attacks by preventing the content to be included in other websites.
Values
- deny: The page cannot be displayed in a frame, regardless of the site attempting to do so.
- sameorigin: The page can only be displayed in a frame on the same origin as the page itself.
- allow-from: Deprecated. Ignored by all modern browsers. Use
ContentSecurityPolicy::new().frame_ancestors(...)instead.
Examples
use helmet_core::XFrameOptions;
let x_frame_options = XFrameOptions::deny();
let x_frame_options = XFrameOptions::same_origin();Variants
Deny
SameOrigin
AllowFrom(String)
👎Deprecated: ALLOW-FROM is ignored by modern browsers. Use ContentSecurityPolicy::new().frame_ancestors(…) instead.
Implementations
Sourceimpl XFrameOptions
impl XFrameOptions
pub fn deny() -> XFrameOptions
pub fn same_origin() -> XFrameOptions
pub fn allow_from(uri: &str) -> XFrameOptions
👎Deprecated: ALLOW-FROM is ignored by modern browsers. Use ContentSecurityPolicy::new().frame_ancestors(…) instead.